==> dnacentersdk-2.4.1.tar.gz: dnacentersdk-2.4.1/dnacentersdk/models/validators/v2_2_2_3/jsd_b95201b6a6905a10b463e036bf591166.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center CreateWirelessProfile data model.

Copyright (c) 2019-2021 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import fastjsonschema
import json
from dnacentersdk.exceptions import MalformedRequest

from builtins import *


class JSONSchemaValidatorB95201B6A6905A10B463E036Bf591166(object):
    """CreateWirelessProfile request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorB95201B6A6905A10B463E036Bf591166, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "profileDetails": {
                "properties": {
                "name": {
                "type": "string"
                },
                "sites": {
                "items": {
                "type": "string"
                },
                "type": "array"
                },
                "ssidDetails": {
                "items": {
                "properties": {
                "enableFabric": {
                "type": "boolean"
                },
                "flexConnect": {
                "properties": {
                "enableFlexConnect": {
                "type": "boolean"
                },
                "localToVlan": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "interfaceName": {
                "type": "string"
                },
                "name": {
                "type": "string"
                },
                "type": {
                "enum": [
                "Guest",
                "Enterprise"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> dnacentersdk-2.6.2.tar.gz: dnacentersdk-2.6.2/dnacentersdk/models/validators/v2_2_1/jsd_b95201b6a6905a10b463e036bf591166.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center createWirelessProfile data model.

Copyright (c) 2019-2021 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import absolute_import, division, print_function, unicode_literals

import json
from builtins import *

import fastjsonschema

from dnacentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorB95201B6A6905A10B463E036Bf591166(object):
    """createWirelessProfile request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorB95201B6A6905A10B463E036Bf591166, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "profileDetails": {
                "properties": {
                "name": {
                "type": "string"
                },
                "sites": {
                "items": {
                "type": "string"
                },
                "type": "array"
                },
                "ssidDetails": {
                "items": {
                "properties": {
                "enableFabric": {
                "type": "boolean"
                },
                "flexConnect": {
                "properties": {
                "enableFlexConnect": {
                "type": "boolean"
                },
                "localToVlan": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "interfaceName": {
                "type": "string"
                },
                "name": {
                "type": "string"
                },
                "type": {
                "enum": [
                "Guest",
                "Enterprise"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )
